        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 31 <br>2,3,5,7,8,9,10,12,14,15,16,17,18,19,23,28,29,30,31,32,34,35,36,37,40,41,42,45,46,48,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 20 <strong>control</strong><br>0,1,4,6,11,13,20,21,22,24,25,26,27,33,38,39,43,44,47,49';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 31 <br>2,3,5,7,8,9,10,12,14,15,16,17,18,19,23,28,29,30,31,32,34,35,36,37,40,41,42,45,46,48,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 20 <strong>control</strong><br>0,1,4,6,11,13,20,21,22,24,25,26,27,33,38,39,43,44,47,49';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 31 <br>2,3,5,7,8,9,10,12,14,15,16,17,18,19,23,28,29,30,31,32,34,35,36,37,40,41,42,45,46,48,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 20 <strong>control</strong><br>0,1,4,6,11,13,20,21,22,24,25,26,27,33,38,39,43,44,47,49';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 31 <br>2,3,5,7,8,9,10,12,14,15,16,17,18,19,23,28,29,30,31,32,34,35,36,37,40,41,42,45,46,48,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 20 <strong>control</strong><br>0,1,4,6,11,13,20,21,22,24,25,26,27,33,38,39,43,44,47,49';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>32</strong> miembros: 31 <br>2,3,5,7,8,9,10,12,14,15,16,17,18,19,23,28,29,30,31,32,34,35,36,37,40,41,42,45,46,48,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260608 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>27</strong> miembros: 20 <strong>control</strong><br>0,1,4,6,11,13,20,21,22,24,25,26,27,33,38,39,43,44,47,49';}
}
